@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: sinfp3.pl 2214 2012-12-02 14:38:04Z gomor $
+# $Id: sinfp3.pl,v 451c3602d7b2 2015/11/25 06:13:53 gomor $
 #
 use strict;
 use warnings;
@@ -114,7 +114,7 @@ if ($lopts{version}) {
    print
       "\n  -- SinFP3 - $Net::SinFP3::VERSION --\n".
       "\n".
-      '   $Id: sinfp3.pl 2214 2012-12-02 14:38:04Z gomor $'."\n".
+      '   $Id: sinfp3.pl,v 451c3602d7b2 2015/11/25 06:13:53 gomor $'."\n".
       "\n  -- Perl modules --\n\n".
       "  o Class::Gomor              - $Class::Gomor::VERSION\n".
       "  o DBD::SQLite               - $DBD::SQLite::VERSION\n".
@@ -604,10 +604,10 @@ Examples:
    sinfp3.pl -mode-passive -search-active -input-sniff -6
 
    # Active fingerprinting of LAN
-   sinfp3.pl -input-arpdiscovery
+   sinfp3.pl -input-arpdiscover
 
    # Active fingerprinting of IPv6 LAN
-   sinfp3.pl -input-arpdiscovery -6
+   sinfp3.pl -input-arpdiscover -6
 
    # Simply SynScan the target
    sinfp3.pl -target example.com -port full -mode-null -search-null -db-null
