@@ -1,11 +1,11 @@
 #
-# $Id: SinFP3.pm 2234 2014-04-08 13:05:14Z gomor $
+# $Id: SinFP3.pm,v 451c3602d7b2 2015/11/25 06:13:53 gomor $
 #
 package Net::SinFP3;
 use strict;
 use warnings;
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 
 use base qw(Class::Gomor::Array DynaLoader);
 our @AS = qw(
@@ -33,20 +33,13 @@ our %EXPORT_TAGS = (
       NS_MATCH_MASK_HEURISTIC1
       NS_MATCH_MASK_HEURISTIC2
    )],
-   functions => [qw(
-      sinfp3_tcp_synscan
-      sinfp3_geterror
-   )],
 );
 
 our @EXPORT_OK = (
    @{$EXPORT_TAGS{matchType}},
    @{$EXPORT_TAGS{matchMask}},
-   @{$EXPORT_TAGS{functions}},
 );
 
-__PACKAGE__->bootstrap($VERSION);
-
 use constant NS_MATCH_TYPE_S1S2S3 => 'S1S2S3';
 use constant NS_MATCH_TYPE_S1S2   => 'S1S2';
 use constant NS_MATCH_TYPE_S2     => 'S2';
@@ -190,6 +183,14 @@ sub _getWorkerModel {
       }
       $model = 'Net::SinFP3::Worker::Thread';
    }
+   elsif ($global->worker =~ /single/i) {
+      eval "use Net::SinFP3::Worker::Single";
+      if ($@) {
+         chomp($@);
+         $log->fatal("Unable to use worker model Single: error [$@]");
+      }
+      $model = 'Net::SinFP3::Worker::Single';
+   }
 
    return $model;
 }
@@ -345,16 +346,6 @@ Arrayref of B<Net::SinFP3::Output> objects.
 
 =back
 
-=head1 FUNCTIONS
-
-=over 4
-
-=item B<sinfp3_geterror>
-
-=item B<sinfp3_tcp_synscan>
-
-=back
-
 =head1 METHODS
 
 =over 4
@@ -375,7 +366,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2011-2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2011-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
