@@ -1,5 +1,5 @@
 #
-# $Id: SinFP3.pm 2234 2014-04-08 13:05:14Z gomor $
+# $Id: SinFP3.pm,v 451c3602d7b2 2015/11/25 06:13:53 gomor $
 #
 package Net::SinFP3::DB::SinFP3;
 use strict;
@@ -515,6 +515,10 @@ sub post {
    my $self = shift;
 
    if ($self->_dbh) {
+      my $prepared = $self->_prepared;
+      for (keys %$prepared) {
+         undef($prepared->{$_});
+      }
       $self->_dbh->disconnect;
    }
 
@@ -529,7 +533,7 @@ sub _updateDb {
 
    my $dbFile = $self->file;
 
-   my $url = "http://www.networecon.com/files/sinfp/sinfp3-latest.db";
+   my $url = "http://www.metabrik.org/wp-content/files/sinfp/sinfp3-latest.db";
    my $db  = $ua->get($url);
    if ($db->is_success) {
       open(my $out, '>', $dbFile) or $log->fatal(
@@ -558,7 +562,7 @@ sub update {
 
    my $dbFile = $self->file;
 
-   my $url = "http://www.networecon.com/files/sinfp/sinfp3-latest.db.md5";
+   my $url = "http://www.metabrik.org/wp-content/files/sinfp/sinfp3-latest.db.md5";
    my $db  = $ua->get($url);
    if ($db->is_success) {
       (my $md5 = $db->decoded_content) =~ s/^.*=\s+(.*)$/$1/;
@@ -594,7 +598,7 @@ Net::SinFP3::DB::SinFP3 - main access to signature database
 
 =head1 DESCRIPTION
 
-Go to http://www.networecon.com/tools/sinfp/ to know more.
+Go to http://www.metabrik.org/sinfp3/ to know more.
 
 =head1 AUTHOR
 
@@ -602,7 +606,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2011-2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2011-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
