@@ -1,5 +1,5 @@
 #
-# $Id: ArpDiscover.pm 2234 2014-04-08 13:05:14Z gomor $
+# $Id: ArpDiscover.pm,v 451c3602d7b2 2015/11/25 06:13:53 gomor $
 #
 package Net::SinFP3::Input::ArpDiscover;
 use strict;
@@ -200,23 +200,9 @@ __END__
 
 Net::SinFP3::Input::ArpDiscover - object describing a SinFP target
 
-=head1 SYNOPSIS
-
-   use Net::SinFP3::Input::IpPort;
-
 =head1 DESCRIPTION
 
-=head1 ATTRIBUTES
-
-=over 4
-
-=back
-
-=head1 METHODS
-
-=over 4
-
-=back
+Go to http://www.metabrik.org/sinfp3/ to know more.
 
 =head1 AUTHOR
 
@@ -224,7 +210,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2011-2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2011-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
