@@ -1,5 +1,5 @@
 #
-# $Id: Signature.pm 2234 2014-04-08 13:05:14Z gomor $
+# $Id: Signature.pm,v 451c3602d7b2 2015/11/25 06:13:53 gomor $
 #
 package Net::SinFP3::Input::Signature;
 use strict;
@@ -139,27 +139,9 @@ __END__
 
 Net::SinFP3::Input::Signature - takes an active signature
 
-=head1 SYNOPSIS
-
-   use Net::SinFP3::Input::Signature;
-
 =head1 DESCRIPTION
 
-=head1 ATTRIBUTES
-
-=head1 METHODS
-
-=over 4
-
-=item B<new>
-
-Object constructor.
-
-=item B<run>
-
-Run this plugin.
-
-=back
+Go to http://www.metabrik.org/sinfp3/ to know more.
 
 =head1 AUTHOR
 
@@ -167,7 +149,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2011-2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2011-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
