@@ -1,5 +1,5 @@
 #
-# $Id: SynScan.pm 2234 2014-04-08 13:05:14Z gomor $
+# $Id: SynScan.pm,v 451c3602d7b2 2015/11/25 06:13:53 gomor $
 #
 package Net::SinFP3::Input::SynScan;
 use strict;
@@ -15,9 +15,9 @@ __PACKAGE__->cgBuildAccessorsScalar(\@AS);
 use Net::SinFP3::Next::IpPort;
 
 use POSIX qw(:sys_wait_h ceil);
-use Net::SinFP3 qw(:functions);
 use Net::Frame::Dump::Online2;
 use Net::Frame::Simple;
+use Net::Write::Fast;
 use Time::Interval;
 
 sub give {
@@ -156,23 +156,22 @@ sub init {
                   "packets[".($retry * $portCount * $targetCount)."]");
 
       if ($ipv6) {
-         my $r = sinfp3_tcp_synscan(
+         my $r = Net::Write::Fast::l4_send_tcp_syn_multi(
             $ip6,
             $targetList,
             $portList,
             $pps,
             $retry,
             $ipv6,
-            0,  # IP not as Int
-            $log->level,
+            $log->level,  # display warnings or not
          );
          if ($r == 0) {
-            $log->fatal(sinfp3_geterror());
+            $log->fatal(Net::Write::Fast::nwf_geterror());
          }
       }
       else {
          # We have to split by chunks of 500_000 elements, to avoid taking to
-         # much memory in one row. And there is a SIGSEGV of we don't do so ;)
+         # much memory in one row. And there is a SIGSEGV if we don't do so ;)
          my $nChunks = ceil($targetCount / 500_000);
          for my $n (0..$nChunks-1) {
             my $first = 500_000 * $n;
@@ -187,18 +186,17 @@ sub init {
             }
 
             my @this = @$targetList[$first..$last];
-            my $r = sinfp3_tcp_synscan(
+            my $r = Net::Write::Fast::l4_send_tcp_syn_multi(
                $ipv6 ? $ip6 : $ip,
                \@this,
                $portList,
                $pps,
                $retry,
                $ipv6,
-               1,
-               $log->level,
+               $log->level,  # display warnings or not
             );
             if ($r == 0) {
-               $log->fatal(sinfp3_geterror());
+               $log->error(Net::Write::Fast::nwf_geterror());
             }
          }
       }
@@ -275,17 +273,17 @@ __END__
 
 Net::SinFP3::Input::SynScan - TCP SYN scanning input method
 
-=head1 SYNOPSIS
-
 =head1 DESCRIPTION
 
+Go to http://www.metabrik.org/sinfp3/ to know more.
+
 =head1 AUTHOR
 
 Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2011-2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2011-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
