@@ -1,5 +1,5 @@
 #
-# $Id: Active.pm 2234 2014-04-08 13:05:14Z gomor $
+# $Id: Active.pm,v 451c3602d7b2 2015/11/25 06:13:53 gomor $
 #
 package Net::SinFP3::Search::Active;
 use strict;
@@ -846,9 +846,9 @@ sub run {
       if (@$result == 0) {
          my $r = Net::SinFP3::Result::Unknown->new(
             global => $self->global,
-            s1     => $mode->s1,
-            s2     => $mode->s2,
-            s3     => $mode->s3,
+            s1     => $mode->s1 || '0',
+            s2     => $mode->s2 || '0',
+            s3     => $mode->s3 || '0',
          );
          $result = [ $r ];
       }
@@ -893,7 +893,7 @@ Net::SinFP3::Search::Active - matching active signatures search engine
 
 =head1 DESCRIPTION
 
-Go to http://www.networecon.com/tools/sinfp/ to know more.
+Go to http://www.metabrik.org/sinfp3/ to know more.
 
 =head1 AUTHOR
 
@@ -901,7 +901,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2011-2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2011-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
